Learn R Programming

eponge (version 0.1.0)

erase_masking: Erase objects from GlobalEnv, which are masking objects from attached packages

Description

Erase objects from GlobalEnv, which are masking objects from attached packages

Usage

erase_masking(pattern = NULL, verbose = FALSE)

erase_masking_functions(pattern = NULL, verbose = FALSE)

Arguments

pattern

a regex pattern

verbose

print removed objects' names

Value

NULL (function returns nothing)

Details

We have to highglight, that for now it only allows us to remove objects from the Global Environment. Be careful: uncontrolled use may cause undesired side effects.

Examples

Run this code
# NOT RUN {
# It works only if objects are assigned in the global environment
matrix <- matrix(0, 3, 3)
gamma <- 0.9
erase_masking()
# }

Run the code above in your browser using DataLab