powered by
Erase objects from GlobalEnv, which are masking objects from attached packages
erase_masking(pattern = NULL, verbose = FALSE)erase_masking_functions(pattern = NULL, verbose = FALSE)
erase_masking_functions(pattern = NULL, verbose = FALSE)
a regex pattern
print removed objects' names
NULL (function returns nothing)
We have to highglight, that for now it only allows us to remove objects from the Global Environment. Be careful: uncontrolled use may cause undesired side effects.
# NOT RUN { # It works only if objects are assigned in the global environment matrix <- matrix(0, 3, 3) gamma <- 0.9 erase_masking() # }
Run the code above in your browser using DataLab